==> komclean-1.1.0.tbz: share/komclean/html/kom.js <==
var kom_command_url = location.protocol + "//" + location.host;
var kom_mainpage_url = "index.html";
var kom_loginpage_url = "login.html";
var kom_threadview_name = "threadview";
var kom_confview_name = "meetinglist";
var kom_instantmessageview_name = "instantmessageview";
var kom_poll_interval = 1000;
var kom_threads_per_page = 50;

var KOM_GROUP_SEPARATOR = "\x1d";
var KOM_RECORD_SEPARATOR = "\x1e";

var lastAsyncUpdate = 0;
var names = null;
var name_lookup = null;

var subconfs = null;

var num_unread = 0;

// Change the favicon when there are unread messages
var favicon_href;
function change_favicon(href)
{
	if (favicon_href != href)
	{
		favicon_href = href;
		var fav_node = document.getElementById('favicon');
		var fav_parent_node = fav_node.parentNode;
		// Must remove and append the node for browsers to react.
		fav_parent_node.removeChild(fav_node);
		fav_node.setAttribute('href', href);
		fav_parent_node.appendChild(fav_node);
	}
}

function kom_update_favicon()
{
	if (kom_has_unread_instant())
		change_favicon("favicon_unread_msg.ico");
	else if (num_unread)
		change_favicon("favicon_unread.ico");
	else
		change_favicon("favicon.ico");

	// Also update the unread marker.
	var has_unread = kom_has_unread_instant() || num_unread;
	document.getElementById("has_unread_marker").style.display = has_unread ? "inline" : "none";
}

var progress_counter = 0;
function kom_begin_progress()
{
	progress_counter++;
	if (progress_counter == 1)
		document.getElementById("progress").style.visibility = "visible";
}
function kom_end_progress()
{
	progress_counter--;
	if (progress_counter == 0)
		document.getElementById("progress").style.visibility = "hidden";
}

function kom_next_unread()
{
	if (!kom_view_next_unread_instant_message())
		kom_view_next_unread_thread();
}

// Register key 'n' as view next thread, suply a function for canceling the
// action when typing in a form
function kom_key_input(e)
{
	var uni_ch = e.charCode ? e.charCode : e.keyCode;
	var ch = String.fromCharCode(uni_ch);
	if (ch=="n" || ch=="N")
	{
		kom_next_unread();
	}
}
function kom_cancel_key(e)
{
	if (!e) var e = window.event;
	e.cancelBubble = true;
	if (e.stopPropagation) e.stopPropagation();
}
document.onkeydown=kom_key_input

// Make links out of urls (and other handy stuff later...)
function kom_postprocess_message(message)
{
	// Match everything that is not space, unless it is ".", ",", ")", "?" or "!" followed by space
	return message.replace(/(https?:\/\/([^\s,).!?](,[^\s]|\)[^\s]|\.[^\s]|![^\s]|\?[^\s])?)*)/g, "<a href='$1' target=_blank>$1</a>");
}

// Handle the current instance
function kom_set_instance(id)
{
	location.hash = "#" + id;
}

function kom_get_instance()
{
	if (location.hash != "")
		return location.hash.substring(1, location.hash.length);
	return "";
}

// Send a command to the backend and return the reply
function kom_command(cmd, async)
{
	var inst = kom_get_instance();
	if (inst == "" && cmd != "version")
		return "ERROR"+KOM_GROUP_SEPARATOR+"Not logged in"
	var req = new XMLHttpRequest();
	if (!req)
	{
		alert("ERROR\nFailed to create XMLHttpRequest");
		return null;
	}

	req.open("POST", kom_command_url+"/" + inst, async);
	req.send(cmd+"\n");
	if (async)
		return "OK";
	if (req.status != 200)
		return "ERROR"+KOM_GROUP_SEPARATOR+"Server error: " + req.status;
	// Replace &, < and > with the html versions of them
	return kom_plain_to_html(req.responseText);
}

// Poll is run all the time to detect updates from the server
function kom_poll_async()
{
	var async = kom_command("poll_async " + lastAsyncUpdate).split(KOM_GROUP_SEPARATOR);
	if (async[0] != "OK")
	{
		// connection lost
		if (kom_get_instance() != "")
			alert("Disconnected from server");
		kom_set_instance("");
		window.location = kom_loginpage_url;
	}
	else
	{
		lastAsyncUpdate = parseInt(async[1]);
		for (var i = 2; i < async.length; ++i)
		{
			var notif = async[i].split(KOM_RECORD_SEPARATOR);
			if (notif[0] == "update_unread")
			{
				kom_update_conference_list();
				if (current_conference >= 0)
				{
					if (current_thread >= 0)
					{
						kom_view_thread(current_thread, current_conference, true);
					}
					else
					{
						kom_view_conference(current_conference, current_conference_offset);
					}
				}
			}
			else if (notif[0] == "update_name")
			{
				kom_update_conference_list();
				names = null;
			}
			else if (notif[0] == "msg")
			{
				kom_add_instant_message(parseInt(notif[1]), parseInt(notif[2]), parseInt(notif[3]), notif[4], parseInt(notif[5]), parseInt(notif[6]));
			}
		}
	}
}

function kom_init()
{
	// Make sure the server is running
	kom_poll_async();
	setInterval(kom_poll_async, kom_poll_interval);
	kom_update_conference_list();
	kom_init_instant_message_starter();
}

function kom_login(srv, usr, pwd, pwdconf, create)
{
	if (create && pwd != pwdconf)
	{
		return;
	}
	var inst = srv + "_" + usr + "_" + Math.floor(Math.random()*1000000);
	kom_set_instance(inst);
	var re = kom_command("login " + KOM_RECORD_SEPARATOR + srv + KOM_RECORD_SEPARATOR + " " + KOM_RECORD_SEPARATOR + usr + KOM_RECORD_SEPARATOR + " " + KOM_RECORD_SEPARATOR + pwd + KOM_RECORD_SEPARATOR + " " + (create?"1":"0"));
	if (re.indexOf("OK") == 0)
	{
		window.location = kom_mainpage_url + "#" + inst;
	}
	else
	{
		kom_set_instance("");
		alert("Failed to login (" + re.split(KOM_GROUP_SEPARATOR)[1] + ")");
	}
}

function kom_name_array_sort(a, b)
{
	a = a[1].toLowerCase();
	a = a.replace(/\([^\)]*\)/g, "");
	a = a.replace(/^\s+/, "");
	b = b[1].toLowerCase();
	b = b.replace(/\([^\)]*\)/g, "");
	b = b.replace(/^\s+/, "");
	if (a < b)
		return -1;
	if (a > b)
		return 1;
	return 0;
}

function kom_lookup_name(id)
{
	if (id <= 0)
	{
		// Less than or equal to zero is not a valid user
		return "&lt;Unknown&gt;";
	}
	if (!names)
	{
		names = new Array();
		name_lookup = new Array();
		var re = kom_command("list_cached_names").split(KOM_GROUP_SEPARATOR);
		if (re[0] == "OK")
		{
			for (var e = 1; e < re.length; ++e)
			{
				var entry = re[e].split(KOM_RECORD_SEPARATOR);
				name_lookup[parseInt(entry[0])] = names.length;
				names.push(entry);
			}
		}
	}
	if (name_lookup[id] != undefined)
		return names[name_lookup[id]][1];

	var re = kom_command("lookup_name_from_id " + id).split(KOM_GROUP_SEPARATOR);
	var entry;
	if (re[0] == "OK")
	{
		entry = re[1].split(KOM_RECORD_SEPARATOR);
	}
	else
	{
		entry = new Array(id, ""+id);
	}
	name_lookup[id] = names.length;
	names.push(entry);
	return entry[1];
}

function kom_prefetch_names(id_list)
{
	if (!names)
	{
		names = new Array();
		name_lookup = new Array();
		var re = kom_command("list_cached_names").split(KOM_GROUP_SEPARATOR);
		if (re[0] == "OK")
		{
			for (var e = 1; e < re.length; ++e)
			{
				var entry = re[e].split(KOM_RECORD_SEPARATOR);
				name_lookup[parseInt(entry[0])] = names.length;
				names.push(entry);
			}
		}
	}
	var prefetch_cmd = "prefetch_names";
	var empty_list = true;
	for (var i = 0; i < id_list.length; ++i)
	{
		if (name_lookup[id_list[i]] == undefined)
		{
			empty_list = false;
			prefetch_cmd += " "+id_list[i];
		}
	}
	if (empty_list)
		return;
	var re = kom_command(prefetch_cmd).split(KOM_GROUP_SEPARATOR);
	if (re[0] == "OK")
	{
		for (var e = 1; e < re.length; ++e)
		{
			var entry = re[e].split(KOM_RECORD_SEPARATOR);
			name_lookup[parseInt(entry[0])] = names.length;
			names.push(entry);
		}
	}
}

function kom_update_conference_list()
{
	subconfs = kom_command("list_subscribed_conferences").split(KOM_GROUP_SEPARATOR);
	if (subconfs[0] != "OK")
		subconfs = new Array();
	else
	{
		for (var i = 1; i < subconfs.length; ++i)
			subconfs[i-1] = subconfs[i].split(KOM_RECORD_SEPARATOR);
		subconfs.pop();
	}
	subconfs.sort(kom_name_array_sort);
	var listelm = document.getElementById(kom_confview_name);
	listelm.innerHTML = "";
	num_unread = 0;
	for (var i = 0; i < subconfs.length; ++i)
	{
		if (!parseInt(subconfs[i][2])||parseInt(subconfs[i][3])||
			(keep_current_conference_in_unread_list && current_conference == subconfs[i][0]))
		{
			var elm = document.createElement("div");
			elm.setAttribute("id", "kom_meeting_"+subconfs[i][0]);
			elm.setAttribute("class", "menuitem");
			elm.setAttribute("onclick", "kom_view_conference("+subconfs[i][0]+",0);return false;");
			elm.innerHTML = "<a href='#'>"+subconfs[i][1]+"</a>";
			listelm.appendChild(elm);
			if (!parseInt(subconfs[i][2])||parseInt(subconfs[i][3]))
			{
				elm.className += " unread";
				num_unread++;
			}
		}
	}
	for (var i = 0; i < subconfs.length; ++i)
	{
		if (parseInt(subconfs[i][2]) && !parseInt(subconfs[i][3]) &&
			!(keep_current_conference_in_unread_list && current_conference == subconfs[i][0]))
		{
			var elm = document.createElement("div");
			elm.setAttribute("id", "kom_meeting_"+subconfs[i][0]);
			elm.setAttribute("class", "menuitem");
			elm.setAttribute("onclick", "kom_view_conference("+subconfs[i][0]+",0);return false;");
			elm.innerHTML = "<a href='#' class='menulink'>"+subconfs[i][1]+"</a>";
			listelm.appendChild(elm);

		}
	}
	if (current_conference >= 0)
		highlight_menu_item("kom_meeting_"+current_conference);
	kom_update_favicon();
}


function toggle_visible(id)
{
	var elm = document.getElementById(id);
	if (elm.style.display != "block")
		elm.style.display = "block";
	else
		elm.style.display = "none";
}
function set_visible(id, visible)
{
	var elm = document.getElementById(id);
	elm.style.display = visible ? "block" : "none";
}

function unhighlight_item(item)
{
	item.className = item.className.replace(/ active/g, "");
}

function unread_item(item)
{
	item.className = item.className.replace(/ unread/g, "");
}

function highlight_menu_item(item_name)
{
	var conference_item = (item_name.indexOf("kom_meeting_") == 0);
	// Remove the highlight of all meetings and highlight users
	var i;
	var listelm = document.getElementById(kom_confview_name);
	for (i = 0; i < listelm.childNodes.length; ++i)
		unhighlight_item(listelm.childNodes[i]);
	listelm = document.getElementById("imesslistview");
	for (i = 0; i < listelm.childNodes.length; ++i)
		unhighlight_item(listelm.childNodes[i]);
	if (!conference_item)
		current_conference = -1;
	unhighlight_item(document.getElementById("menu_new_mess"));
	unhighlight_item(document.getElementById("menu_new_chat"));
	unhighlight_item(document.getElementById("meeting_subscriptions"));
	unhighlight_item(document.getElementById("user_list"));
	unhighlight_item(document.getElementById("kom_meeting_0"));
	unhighlight_item(document.getElementById("kom_meeting_-2"));

	if (document.getElementById(item_name))
		document.getElementById(item_name).className += " active";
	else if (conference_item)
		current_conference = -1;
	if (keep_current_conference_in_unread_list && item_name != ("kom_meeting_"+current_conference))
	{
		keep_current_conference_in_unread_list = false;
		setTimeout("kom_update_conference_list();", 0);
	}
}

function kom_plain_to_html(msg)
{
	var re = msg.replace(/&/g, "&amp;");
	re = re.replace(/</g, "&lt;");
	return re.replace(/>/g, "&gt;");
}

function kom_html_to_plain(msg)
{
	var re = msg.replace(/&lt;/g, "<");
	re = re.replace(/&gt;/g, ">");
	return re.replace(/&amp;/g, "&");
}

==> komclean-1.2.0.tbz: share/komclean/html/kom.js <==
var kom_command_url = location.protocol + "//" + location.host;
var kom_mainpage_url = "index.html";
var kom_loginpage_url = "login.html";
var kom_threadview_name = "threadview";
var kom_confview_name = "meetinglist";
var kom_instantmessageview_name = "instantmessageview";
var kom_poll_interval = 1000;
var kom_threads_per_page = 50;

var KOM_GROUP_SEPARATOR = "\x1d";
var KOM_RECORD_SEPARATOR = "\x1e";

var lastAsyncUpdate = 0;
var names = null;
var name_lookup = null;

var subconfs = null;

var num_unread = 0;

// Change the favicon when there are unread messages
var favicon_href;
function change_favicon(href)
{
	if (favicon_href != href)
	{
		favicon_href = href;
		var fav_node = document.getElementById('favicon');
		var fav_parent_node = fav_node.parentNode;
		// Must remove and append the node for browsers to react.
		fav_parent_node.removeChild(fav_node);
		fav_node.setAttribute('href', href);
		fav_parent_node.appendChild(fav_node);
	}
}

function kom_update_favicon()
{
	if (kom_has_unread_instant())
		change_favicon("favicon_unread_msg.ico");
	else if (num_unread)
		change_favicon("favicon_unread.ico");
	else
		change_favicon("favicon.ico");

	// Also update the unread marker.
	var has_unread = kom_has_unread_instant() || num_unread;
	document.getElementById("has_unread_marker").style.display = has_unread ? "inline" : "none";
}

var progress_counter = 0;
function kom_begin_progress()
{
	progress_counter++;
	if (progress_counter == 1)
		document.getElementById("progress").style.visibility = "visible";
}
function kom_end_progress()
{
	progress_counter--;
	if (progress_counter == 0)
		document.getElementById("progress").style.visibility = "hidden";
}

function kom_next_unread()
{
	if (!kom_view_next_unread_instant_message())
		kom_view_next_unread_thread();
}

// Register key 'n' as view next thread, suply a function for canceling the
// action when typing in a form
function kom_key_input(e)
{
	var uni_ch = e.charCode ? e.charCode : e.keyCode;
	var ch = String.fromCharCode(uni_ch);
	if (!(e.ctrlKey || e.altKey || e.metaKey) && (ch=="n" || ch=="N"))
	{
		kom_next_unread();
	}
}
function kom_cancel_key(e)
{
	if (!e) var e = window.event;
	e.cancelBubble = true;
	if (e.stopPropagation) e.stopPropagation();
}
document.onkeydown=kom_key_input

// Make links out of urls (and other handy stuff later...)
function kom_postprocess_message(message)
{
	// Match everything that is not space, unless it is ".", ",", ")", "?" or "!" followed by space
	return message.replace(/(https?:\/\/([^\s,).!?](,[^\s]|\)[^\s]|\.[^\s]|![^\s]|\?[^\s])?)*)/g, "<a href='$1' target=_blank>$1</a>");
}

// Handle the current instance
function kom_set_instance(id)
{
	location.hash = "#" + id;
}

function kom_get_instance()
{
	if (location.hash != "")
		return location.hash.substring(1, location.hash.length);
	return "";
}

// Send a command to the backend and return the reply
function kom_command(cmd, async)
{
	var inst = kom_get_instance();
	if (inst == "" && cmd != "version" && cmd != "upgrade_message")
		return "ERROR"+KOM_GROUP_SEPARATOR+"Not logged in"
	var req = new XMLHttpRequest();
	if (!req)
	{
		alert("ERROR\nFailed to create XMLHttpRequest");
		return null;
	}

	req.open("POST", kom_command_url+"/" + inst, async);
	req.send(cmd+"\n");
	if (async)
		return "OK";
	if (req.status != 200)
		return "ERROR"+KOM_GROUP_SEPARATOR+"Server error: " + req.status;
	// Replace &, < and > with the html versions of them
	return kom_plain_to_html(req.responseText);
}

// Poll is run all the time to detect updates from the server
function kom_poll_async()
{
	var async = kom_command("poll_async " + lastAsyncUpdate).split(KOM_GROUP_SEPARATOR);
	if (async[0] != "OK")
	{
		if (kom_get_instance() != "")
		{
			// connection lost
			if (async[1] == "Not connected")
			{
				alert("Disconnected from server");
			}
			else if (async[1] == "Reconnecting")
			{
				document.getElementById('reconnect_dimlayer').style.visibility='visible';
				return;
			}
			else
				alert("Error: " + async[1]);
		}
		kom_set_instance("");
		window.location = kom_loginpage_url;
	}
	else
	{
		var recon = document.getElementById('reconnect_dimlayer');
		if (recon.style.visibility=='visible')
		{
			recon.style.visibility='hidden';
			// Reload most data
			names = null;
			kom_update_conference_list();
			if (current_conference >= 0)
			{
				if (current_thread >= 0)
				{
					kom_view_thread(current_thread, current_conference, true);
				}
				else
				{
					kom_view_conference(current_conference, current_conference_offset);
				}
			}
		}
		lastAsyncUpdate = parseInt(async[1]);
		for (var i = 2; i < async.length; ++i)
		{
			var notif = async[i].split(KOM_RECORD_SEPARATOR);
			if (notif[0] == "update_unread")
			{
				kom_update_conference_list();
				if (current_conference >= 0)
				{
					if (current_thread >= 0)
					{
						kom_view_thread(current_thread, current_conference, true);
					}
					else
					{
						kom_view_conference(current_conference, current_conference_offset);
					}
				}
			}
			else if (notif[0] == "update_name")
			{
				kom_update_conference_list();
				names = null;
			}
			else if (notif[0] == "msg")
			{
				kom_add_instant_message(parseInt(notif[1]), parseInt(notif[2]), parseInt(notif[3]), notif[4], parseInt(notif[5]), parseInt(notif[6]));
			}
		}
	}
}

function kom_init()
{
	// Make sure the server is running
	kom_poll_async();
	setInterval(kom_poll_async, kom_poll_interval);
	kom_update_conference_list();
	kom_init_instant_message_starter();
}

function kom_login(srv, usr, pwd, pwdconf, create)
{
	if (create && pwd != pwdconf)
	{
		return;
	}
	var inst = srv + "_" + usr + "_" + Math.floor(Math.random()*1000000);
	kom_set_instance(inst);
	var re = kom_command("login " + KOM_RECORD_SEPARATOR + srv + KOM_RECORD_SEPARATOR + " " + KOM_RECORD_SEPARATOR + usr + KOM_RECORD_SEPARATOR + " " + KOM_RECORD_SEPARATOR + pwd + KOM_RECORD_SEPARATOR + " " + (create?"1":"0"));
	if (re.indexOf("OK") == 0)
	{
		window.location = kom_mainpage_url + "#" + inst;
	}
	else
	{
		kom_set_instance("");
		alert("Failed to login (" + re.split(KOM_GROUP_SEPARATOR)[1] + ")");
	}
}

function kom_name_array_sort(a, b)
{
	a = a[1].toLowerCase();
	a = a.replace(/\([^\)]*\)/g, "");
	a = a.replace(/^\s+/, "");
	b = b[1].toLowerCase();
	b = b.replace(/\([^\)]*\)/g, "");
	b = b.replace(/^\s+/, "");
	if (a < b)
		return -1;
	if (a > b)
		return 1;
	return 0;
}

function kom_lookup_name(id)
{
	if (id <= 0)
	{
		// Less than or equal to zero is not a valid user
		return "&lt;Unknown&gt;";
	}
	if (!names)
	{
		names = new Array();
		name_lookup = new Array();
		var re = kom_command("list_cached_names").split(KOM_GROUP_SEPARATOR);
		if (re[0] == "OK")
		{
			for (var e = 1; e < re.length; ++e)
			{
				var entry = re[e].split(KOM_RECORD_SEPARATOR);
				name_lookup[parseInt(entry[0])] = names.length;
				names.push(entry);
			}
		}
	}
	if (name_lookup[id] != undefined)
		return names[name_lookup[id]][1];

	var re = kom_command("lookup_name_from_id " + id).split(KOM_GROUP_SEPARATOR);
	var entry;
	if (re[0] == "OK")
	{
		entry = re[1].split(KOM_RECORD_SEPARATOR);
	}
	else
	{
		entry = new Array(id, ""+id);
	}
	name_lookup[id] = names.length;
	names.push(entry);
	return entry[1];
}

function kom_prefetch_names(id_list)
{
	if (!names)
	{
		names = new Array();
		name_lookup = new Array();
		var re = kom_command("list_cached_names").split(KOM_GROUP_SEPARATOR);
		if (re[0] == "OK")
		{
			for (var e = 1; e < re.length; ++e)
			{
				var entry = re[e].split(KOM_RECORD_SEPARATOR);
				name_lookup[parseInt(entry[0])] = names.length;
				names.push(entry);
			}
		}
	}
	var prefetch_cmd = "prefetch_names";
	var empty_list = true;
	for (var i = 0; i < id_list.length; ++i)
	{
		if (name_lookup[id_list[i]] == undefined)
		{
			empty_list = false;
			prefetch_cmd += " "+id_list[i];
		}
	}
	if (empty_list)
		return;
	var re = kom_command(prefetch_cmd).split(KOM_GROUP_SEPARATOR);
	if (re[0] == "OK")
	{
		for (var e = 1; e < re.length; ++e)
		{
			var entry = re[e].split(KOM_RECORD_SEPARATOR);
			name_lookup[parseInt(entry[0])] = names.length;
			names.push(entry);
		}
	}
}

function kom_update_conference_list()
{
	subconfs = kom_command("list_subscribed_conferences").split(KOM_GROUP_SEPARATOR);
	if (subconfs[0] != "OK")
		subconfs = new Array();
	else
	{
		for (var i = 1; i < subconfs.length; ++i)
			subconfs[i-1] = subconfs[i].split(KOM_RECORD_SEPARATOR);
		subconfs.pop();
	}
	subconfs.sort(kom_name_array_sort);
	var listelm = document.getElementById(kom_confview_name);
	listelm.innerHTML = "";
	num_unread = 0;
	for (var i = 0; i < subconfs.length; ++i)
	{
		if (!parseInt(subconfs[i][2])||parseInt(subconfs[i][3])||
			(keep_current_conference_in_unread_list && current_conference == subconfs[i][0]))
		{
			var elm = document.createElement("div");
			elm.setAttribute("id", "kom_meeting_"+subconfs[i][0]);
			elm.setAttribute("class", "menuitem");
			elm.setAttribute("onclick", "kom_view_conference("+subconfs[i][0]+",0);return false;");
			elm.innerHTML = "<a href='#'>"+subconfs[i][1]+"</a>";
			listelm.appendChild(elm);
			if (!parseInt(subconfs[i][2])||parseInt(subconfs[i][3]))
			{
				elm.className += " unread";
				num_unread++;
			}
		}
	}
	for (var i = 0; i < subconfs.length; ++i)
	{
		if (parseInt(subconfs[i][2]) && !parseInt(subconfs[i][3]) &&
			!(keep_current_conference_in_unread_list && current_conference == subconfs[i][0]))
		{
			var elm = document.createElement("div");
			elm.setAttribute("id", "kom_meeting_"+subconfs[i][0]);
			elm.setAttribute("class", "menuitem");
			elm.setAttribute("onclick", "kom_view_conference("+subconfs[i][0]+",0);return false;");
			elm.innerHTML = "<a href='#' class='menulink'>"+subconfs[i][1]+"</a>";
			listelm.appendChild(elm);

		}
	}
	if (current_conference >= 0)
		highlight_menu_item("kom_meeting_"+current_conference);
	kom_update_favicon();
}


function toggle_visible(id)
{
	var elm = document.getElementById(id);
	if (elm.style.display != "block")
		elm.style.display = "block";
	else
		elm.style.display = "none";
}
function set_visible(id, visible)
{
	var elm = document.getElementById(id);
	elm.style.display = visible ? "block" : "none";
}

function unhighlight_item(item)
{
	item.className = item.className.replace(/ active/g, "");
}

function unread_item(item)
{
	item.className = item.className.replace(/ unread/g, "");
}

function highlight_menu_item(item_name)
{
	// Hide presentation popup if visible
	HidePresentationPopup();

	var conference_item = (item_name.indexOf("kom_meeting_") == 0);
	// Remove the highlight of all meetings and highlight users
	var i;
	var listelm = document.getElementById(kom_confview_name);
	for (i = 0; i < listelm.childNodes.length; ++i)
		unhighlight_item(listelm.childNodes[i]);
	listelm = document.getElementById("imesslistview");
	for (i = 0; i < listelm.childNodes.length; ++i)
		unhighlight_item(listelm.childNodes[i]);
	if (!conference_item)
		current_conference = -1;
	unhighlight_item(document.getElementById("menu_new_mess"));
	unhighlight_item(document.getElementById("menu_new_chat"));
	unhighlight_item(document.getElementById("meeting_subscriptions"));
	unhighlight_item(document.getElementById("user_list"));
	unhighlight_item(document.getElementById("kom_meeting_0"));
	unhighlight_item(document.getElementById("kom_meeting_-2"));

	if (document.getElementById(item_name))
		document.getElementById(item_name).className += " active";
	else if (conference_item)
		current_conference = -1;
	if (keep_current_conference_in_unread_list && item_name != ("kom_meeting_"+current_conference))
	{
		keep_current_conference_in_unread_list = false;
		setTimeout("kom_update_conference_list();", 0);
	}
}

function kom_plain_to_html(msg)
{
	var re = msg.replace(/&/g, "&amp;");
	re = re.replace(/</g, "&lt;");
	return re.replace(/>/g, "&gt;");
}

function kom_html_to_plain(msg)
{
	var re = msg.replace(/&lt;/g, "<");
	re = re.replace(/&gt;/g, ">");
	return re.replace(/&amp;/g, "&");
}

var current_popup = -1;
function HidePopup()
{
	var elm = document.getElementById(current_popup);
	if (elm)
		elm.style.display = "none";
	current_popup = -1;
	return elm ? true : false;
}

function ShowPopup(id, target_elm, html)
{
	HidePopup();
	current_popup = id;
	var elm = document.getElementById(id);
	if (!elm)
	{
		elm = document.createElement("div");
		elm.setAttribute("id", id);
		elm.setAttribute("style", "position: absolute; display: none;");
		document.body.appendChild(elm);
	}
	elm.innerHTML = html;

	var iobj = target_elm, xpos = 0, ypos = target_elm.offsetHeight;
	while (iobj) {
		xpos = xpos + iobj.offsetLeft;
		ypos = ypos + iobj.offsetTop;
		iobj = iobj.offsetParent;
	}
	elm.style.left = xpos + "px";
	elm.style.top = ypos + "px";
	elm.style.display = "block";
	return elm;
}

function HidePresentationPopup()
{
	HidePopup();
}

function ChatWith(conf) {
	HidePresentationPopup();
	start_new_instant_message_session_byconf(conf);
}

function ShowPresentationPopup(event, node)
{
	HidePresentationPopup();

	var id = node.parentNode.parentNode.userid;
	var infopopup_target = node.parentNode;
	var desc = kom_command("conference_info " + id).split(KOM_GROUP_SEPARATOR);
	if (desc[0] == "OK")
	{
		desc = desc[1].split(KOM_RECORD_SEPARATOR);
		var presentation = desc[2];
		presentation = presentation.replace(/.*\n/, "").replace(/^\s*|\s*$/g,'');
		var html = kom_postprocess_message(presentation);
		if (html == "")
			html = "No description available";
		var pre_html = "<header><input type='button' value='Chat with' onclick='ChatWith(" + id + ")'> <button class='closebtn' onclick='HidePresentationPopup()'><img src='img/close.png'></button> </header>";
		ShowPopup("info_popup", infopopup_target, pre_html + "<div>" + html + "</div>");
	}
	event.cancelBubble = true;
	return false;
}
